@@ -10,7 +10,7 @@ use constant {
     NEG_TWO_32    => -4294967296.0,
 };
 
-our $VERSION = "0.22";
+our $VERSION = "0.23";
 
 require Algorithm::HyperLogLog;
 
@@ -112,6 +112,19 @@ sub estimate {
     return $estimate;
 }
 
+sub merge {
+    my ($self, $other) = @_;
+    my $m    = $self->{m};
+
+    die "hll size misatch" if $self->{m} != $other->{m};
+
+    for (my $i=0; $i<$m; $i++) {
+        if ($self->{registers}[$i] < $other->{registers}[$i]) {
+            $self->{registers}[$i] = $other->{registers}[$i];
+        }
+    }
+}
+
 sub XS {
     0;
 }
